//  Skoda 110R Suspension Geometry file by mackosajt (HKV Team, www.HKV.hu)
//////////////////////////////////////////////////////////////////////////
//
// Conventions:
//
// +x = left
// +z = rear
// +y = up
// +pitch = nose up
// +yaw = nose right
// +roll = right
//
// [BODY]  - a rigid mass with mass and inertial properties
// [JOINT] - a ball joint constraining an offset of one body to an
//           offset of another body (eliminates 3 DOF)
// [HINGE] - a constraint restricting the relative rotations of two
//           bodies to be around a single axis (eliminates 2 DOF).
// [BAR]   - a constraint holding an offset of one body from an offset of
//           another body at a fixed distance (eliminates 1 DOF).
// [JOINT&HINGE] - both the joint and hinge constraints, forming the
//           conventional definition of a hinge (eliminates 5 DOF).
//
//////////////////////////////////////////////////////////////////////////

// Body including all rigidly attached parts (wings, barge boards, etc.)
[BODY]
name=body mass=(1.0) inertia=(1.0,1.0,1.0)
pos=(0.0,0.00,0.0) ori=(0.0,0.0,0.0)

// Front spindles
[BODY]
name=fl_spindle mass=(18.0) inertia=(0.0275,0.0260,0.0245)
pos=(0.640,0.0,-1.05) ori=(0.0,0.0,0.0)

[BODY]
name=fr_spindle mass=(18.0) inertia=(0.0275,0.0260,0.0245)
pos=(-0.640,0.0,-1.05) ori=(0.0,0.0,0.0)

// Front wheels
[BODY]
name=fl_wheel mass=(25.0) inertia=(2.250,1.000,1.000)
pos=(0.6555,0.0,-1.05) ori=(0.0,0.0,0.0)

[BODY]
name=fr_wheel mass=(25.0) inertia=(2.250,1.000,1.000)
pos=(-0.6555,0.0,-1.05) ori=(0.0,0.0,0.0)

// Rear spindles
[BODY]
name=rl_spindle mass=(18.0) inertia=(0.0275,0.0260,0.0245)
pos=(0.625,0.0,1.35) ori=(0.0,0.0,0.0)

[BODY]
name=rr_spindle mass=(18.0) inertia=(0.0275,0.0260,0.0245)
pos=(-0.625,0.0,1.35) ori=(0.0,0.0,0.0)

// Rear wheels 
[BODY]
name=rl_wheel mass=(25.0) inertia=(2.250,1.000,1.000)
pos=(0.625,0.0,1.35) ori=(0.0,0.0,0.0)

[BODY]
name=rr_wheel mass=(25.0) inertia=(2.250,1.000,1.000)
pos=(-0.625,0.0,1.35) ori=(0.0,0.0,0.0)

// Fuel in tank is not rigidly attached - it is attached with springs and
// dampers to simulate movement.  Properties are defined in the HDV file.

[BODY]
name=fuel_tank mass=(1.5) inertia=(1.0,1.0,1.0)
pos=(0.0,0.0,0.0) ori=(0.0,0.0,0.0)

// Driver's head is not rigidly attached, and it does NOT affect the vehicle
// physics.  Position is from the eyepoint defined in the VEH file, while
// other properties are defined in the head physics file.

[BODY]
name=driver_head mass=(6.0) inertia=(0.02,0.02,0.02)
pos=(0.0,0.0,0.0) ori=(0.0,0.0,0.0)


//////////////////////////////////////////////////////////////////////////
//
// Constraints
//
//////////////////////////////////////////////////////////////////////////
//Simulated Strut Suspension
// Front wheel and spindle connections
[JOINT&HINGE]
posbody=fl_wheel negbody=fl_spindle pos=fl_wheel axis=(-1.0,0.0,0.0)

[JOINT&HINGE]
posbody=fr_wheel negbody=fr_spindle pos=fr_wheel axis=(1.0,0.0,0.0)


// Front left suspension (2 A-arms + 1 steering arm = 5 links)
[BAR] // forward upper arm
name=fl_fore_upper posbody=body negbody=fl_spindle pos=(0.44, 0.14, -1.100) neg=(0.578, 0.14, -1.050)

[BAR] // rearward upper arm
posbody=body negbody=fl_spindle pos=(0.44, 0.14, -0.950) neg=(0.578, 0.14, -1.050)

[BAR] // forward lower arm
posbody=body negbody=fl_spindle pos=(0.295, -0.076, -1.150) neg=(0.60, -0.08, -1.050)

[BAR] // rearward lower arm
name=fl_fore_lower posbody=body negbody=fl_spindle pos=(0.295, -0.076, -0.950) neg=(0.60, -0.08, -1.050)

[BAR] // steering arm (must be named for identification)
name=fl_steering posbody=body negbody=fl_spindle pos=(0.380, 0.015, -0.870) neg=(0.590, 0.015, -0.902)

// Front right suspension (2 A-arms + 1 steering arm = 5 links)
[BAR] // forward upper arm (used in steering lock calculation)
name=fr_fore_upper posbody=body negbody=fr_spindle pos=(-0.44, 0.14, -1.100) neg=(-0.578, 0.14, -1.050)

[BAR] // rearward upper arm
posbody=body negbody=fr_spindle pos=(-0.44, 0.14, -0.950) neg=(-0.578, 0.14, -1.050)

[BAR] // forward lower arm
name=fr_fore_lower posbody=body negbody=fr_spindle pos=(-0.295, -0.076, -1.150) neg=(-0.60,-0.08, -1.050)

[BAR] // rearward lower arm
posbody=body negbody=fr_spindle pos=(-0.295, -0.076, -0.950) neg=(-0.60, -0.08,-1.050)

[BAR] // steering arm (must be named for identification)
name=fr_steering posbody=body negbody=fr_spindle pos=(-0.380, 0.015, -0.870) neg=(-0.590, 0.015, -0.902)

// Rear left suspension (2 A-arms + 1 straight link = 5 links)
[BAR] // forward upper arm
posbody=body negbody=rl_spindle pos=(0.500,0.00,0.865) neg=(0.500,0.000,1.350)

[BAR] // rearward upper arm
posbody=body negbody=rl_spindle pos=(0.150,0.000,1.350) neg=(0.500,0.000,1.350)

[BAR] // forward lower arm
posbody=body negbody=rl_spindle pos=(0.500,-0.00,0.865) neg=(0.500,-0.085,1.350)

[BAR] // rearward lower arm
posbody=body negbody=rl_spindle pos=(0.150,-0.085,1.350) neg=(0.500,-0.085,1.350)

[BAR] // straight link
posbody=body negbody=rl_spindle pos=(0.150,-0.00,1.350) neg=(0.500,0.0,1.450)

// Rear right suspension (2 A-arms + 1 straight link = 5 links)
[BAR] // forward upper arm
posbody=body negbody=rr_spindle pos=(-0.500,0.00,0.865) neg=(-0.500,0.000,1.350)

[BAR] // rearward upper arm
posbody=body negbody=rr_spindle pos=(-0.150,0.000,1.350) neg=(-0.500,0.000,1.350)

[BAR] // forward lower arm
posbody=body negbody=rr_spindle pos=(-0.500,-0.00,0.865) neg=(-0.500,-0.085,1.350)

[BAR] // rearward lower arm
posbody=body negbody=rr_spindle pos=(-0.150,-0.085,1.350) neg=(-0.500,-0.085,1.350)

[BAR] // straight link
posbody=body negbody=rr_spindle pos=(-0.150,-0.00,1.350) neg=(-0.500,0.0,1.450)

// Rear spindle and wheel connections 
[JOINT&HINGE]
posbody=rl_wheel negbody=rl_spindle pos=rl_wheel axis=(-1.0,0.0,0.0)

[JOINT&HINGE]
posbody=rr_wheel negbody=rr_spindle pos=rr_wheel axis=(1.0,0.0,0.0)